# Generated by Django 3.2.11 on 2022-02-24 12:09

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_microbiology", "0004_auto_20220223_2258"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmicrobiology",
            name="tissue_biopsy_organism_text",
            field=models.TextField(
                blank=True, null=True, verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AddField(
            model_name="microbiology",
            name="tissue_biopsy_organism_text",
            field=models.TextField(
                blank=True, null=True, verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="tissue_biopsy_organism",
            field=models.CharField(
                choices=[
                    ("cryptococcus_neoformans", "Cryptococcus neoformans"),
                    ("mycobacterium_tuberculosis", "Mycobacterium Tuberculosis"),
                    ("OTHER", "Other"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=50,
                verbose_name="If growth POSITIVE, organism",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="tissue_biopsy_organism",
            field=models.CharField(
                choices=[
                    ("cryptococcus_neoformans", "Cryptococcus neoformans"),
                    ("mycobacterium_tuberculosis", "Mycobacterium Tuberculosis"),
                    ("OTHER", "Other"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=50,
                verbose_name="If growth POSITIVE, organism",
            ),
        ),
    ]



from datetime import date

from django.db import models
from django.db.models import PROTECT
from edc_crf.model_mixins import CrfModelMixin
from edc_identifier.managers import SubjectIdentifierManager
from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
from edc_model.models import BaseUuidModel
from edc_registration.model_mixins import UpdatesOrCreatesRegistrationModelMixin
from edc_screening.model_mixins import ScreeningModelMixin
from edc_sites.models import SiteModelMixin
from edc_utils import get_utcnow
from edc_visit_schedule.model_mixins import OffScheduleModelMixin, OnScheduleModelMixin
from edc_visit_tracking.models import SubjectVisit


class SubjectScreening(ScreeningModelMixin, BaseUuidModel):
    objects = SubjectIdentifierManager()


class SubjectConsent(
    SiteModelMixin,
    NonUniqueSubjectIdentifierFieldMixin,
    UpdatesOrCreatesRegistrationModelMixin,
    BaseUuidModel,
):
    report_datetime = models.DateTimeField(default=get_utcnow)

    consent_datetime = models.DateTimeField(default=get_utcnow)

    version = models.CharField(max_length=25, default="1")

    identity = models.CharField(max_length=25)

    confirm_identity = models.CharField(max_length=25)

    dob = models.DateField(default=date(1995, 1, 1))


class OnSchedule(SiteModelMixin, OnScheduleModelMixin, BaseUuidModel):
    pass


class OffSchedule(SiteModelMixin, OffScheduleModelMixin, BaseUuidModel):
    pass


class CrfOne(CrfModelMixin, BaseUuidModel):
    subject_visit = models.ForeignKey(SubjectVisit, on_delete=PROTECT)

    report_datetime = models.DateTimeField(default=get_utcnow)

    f1 = models.CharField(max_length=50, null=True, blank=True)

    f2 = models.CharField(max_length=50, null=True, blank=True)

    f3 = models.CharField(max_length=50, null=True, blank=True)

    next_appt_date = models.DateField(null=True, blank=True)

    next_visit_code = models.CharField(max_length=50, null=True, blank=True)



# Generated by Django 4.2.5 on 2023-09-25 15:43

import _socket
import django.db.models.manager
import django_audit_fields.fields.hostname_modification_field
import edc_sites.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_microbiology", "0009_auto_20220711_1230"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="microbiology",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Microbiology",
                "verbose_name_plural": "Microbiology",
            },
        ),
        migrations.AlterModelManagers(
            name="microbiology",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
    ]



from django.contrib import admin
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
from edc_model_admin.history import SimpleHistoryAdmin

from .admin_site import edc_microbiology_admin
from .forms import MicrobiologyForm
from .modeladmin_mixins import MicrobiologyModelAdminMixin
from .models import Microbiology


@admin.register(Microbiology, site=edc_microbiology_admin)
class MicrobiologyAdmin(
    MicrobiologyModelAdminMixin, ModelAdminSubjectDashboardMixin, SimpleHistoryAdmin
):
    form = MicrobiologyForm



from django.contrib import admin
from django_audit_fields import audit_fieldset_tuple

from ..fieldsets import (
    get_sputum_afb_fieldset,
    get_sputum_culture_fieldset,
    get_sputum_genexpert_fieldset,
    get_urinary_lam_fieldset,
    get_urine_culture_fieldset,
)


class MicrobiologyModelAdminMixin:
    fieldsets = (
        get_urinary_lam_fieldset(),
        get_sputum_genexpert_fieldset(),
        get_sputum_culture_fieldset(),
        get_sputum_afb_fieldset(),
        get_urine_culture_fieldset(),
        audit_fieldset_tuple,
    )

    radio_fields = {
        "sputum_afb_performed": admin.VERTICAL,
        "sputum_afb_result": admin.VERTICAL,
        "sputum_culture_performed": admin.VERTICAL,
        "sputum_culture_result": admin.VERTICAL,
        "sputum_genexpert_result": admin.VERTICAL,
        "sputum_genexpert_performed": admin.VERTICAL,
        "urinary_lam_performed": admin.VERTICAL,
        "urinary_lam_result": admin.VERTICAL,
        "urinary_lam_result_grade": admin.VERTICAL,
    }



from edc_constants.constants import IND, NEG, NOT_APPLICABLE, OTHER, POS, UNKNOWN

from .constants import (
    BACTERIA,
    CRYPTOCOCCUS_NEOFORMANS,
    ECOLI,
    KLEBSIELLA_SPP,
    LAM_POS1,
    LAM_POS2,
    LAM_POS3,
    LAM_POS4,
    LAM_POS5,
    NO_GROWTH,
)

BACTERIA_TYPE = (
    (NOT_APPLICABLE, "Not applicable"),
    (ECOLI, "E.coli"),
    (KLEBSIELLA_SPP, "Klebsiella spp."),
    ("streptococcus_pneumoniae", "Streptococcus pneumoniae"),
    ("staphylococus_aureus", "(Sensitive) Staphylococus aureus"),
    ("mrsa", "MRSA"),
    (OTHER, "Other"),
)

BLOOD_CULTURE_RESULTS_ORGANISM = (
    (NOT_APPLICABLE, "Not applicable"),
    (CRYPTOCOCCUS_NEOFORMANS, "Cryptococcus neoformans"),
    (BACTERIA, "Bacteria"),
    ("bacteria_and_cryptococcus", "Bacteria and Cryptococcus"),
    (OTHER, "Other"),
)

BIOPSY_RESULTS_ORGANISM = (
    (CRYPTOCOCCUS_NEOFORMANS, "Cryptococcus neoformans"),
    ("mycobacterium_tuberculosis", "Mycobacterium Tuberculosis"),
    (OTHER, "Other"),
    (NOT_APPLICABLE, "Not applicable"),
)

CULTURE_RESULTS = (
    (POS, "Positive"),
    (NO_GROWTH, "No growth"),
    (NOT_APPLICABLE, "Not applicable"),
)

LAM_POS_RESULT = (
    (LAM_POS1, "1+ (low)"),
    (LAM_POS2, "2+"),
    (LAM_POS3, "3+"),
    (LAM_POS4, "4+"),
    (LAM_POS5, "5+ (high)"),
    (UNKNOWN, "Unknown / Grade not reported"),
    (NOT_APPLICABLE, "Not applicable"),
)

URINE_CULTURE_RESULTS_ORGANISM = (
    (NOT_APPLICABLE, "Not applicable"),
    (ECOLI, "E.coli"),
    (KLEBSIELLA_SPP, "Klebsiella spp."),
    (OTHER, "Other"),
)

SPUTUM_GENEXPERT = (
    (POS, "MTB Positive"),
    (NEG, "MTB Negative"),
    (IND, "Indeterminate"),
    (NOT_APPLICABLE, "Not applicable"),
)


SPUTUM_CULTURE = (
    (POS, "MTB Positive"),
    (NEG, "MTB Negative"),
    (IND, "Indeterminate / contaminated"),
    (NOT_APPLICABLE, "Not applicable"),
)



from .blood_culture import BloodCultureModelMixin
from .csf_genexpert import CsfGeneXpertModelMixin
from .histopathology import HistopathologyModelMixin
from .sputum_afb import SputumAfbModelMixin
from .sputum_culture import SputumCultureModelMixin
from .sputum_genexpert import SputumGenexpertModelMixin
from .urinary_lam import UrinaryLamModelMixin
from .urine_culture import UrineCultureModelMixin



from django.contrib import admin
from django.urls import include, path
from django.views.generic import RedirectView

app_name = "microbiology_app"


urlpatterns = []


urlpatterns += [
    path("admin/", admin.site.urls),
    path("i18n/", include("django.conf.urls.i18n")),
    path("", RedirectView.as_view(url="admin/"), name="logout"),
]



from django.contrib import admin
from django_audit_fields import audit_fieldset_tuple

from ..fieldsets import get_histopathology_fieldset


class HistopathologyModelAdminMixin:
    fieldsets = (
        get_histopathology_fieldset(),
        audit_fieldset_tuple,
    )

    radio_fields = {
        "tissue_biopsy_performed": admin.VERTICAL,
        "tissue_biopsy_result": admin.VERTICAL,
        "tissue_biopsy_organism": admin.VERTICAL,
    }



from django.db import models
from edc_constants.choices import YES_NO_NA
from edc_constants.constants import NOT_APPLICABLE
from edc_model.validators import date_not_future
from edc_protocol.validators import date_not_before_study_start

from ..choices import SPUTUM_GENEXPERT


class SputumGenexpertModelMixin(models.Model):
    sputum_genexpert_performed = models.CharField(
        verbose_name="Sputum Gene-Xpert performed?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    sputum_genexpert_date = models.DateField(
        verbose_name="Sputum Gene-Xpert date",
        validators=[date_not_before_study_start, date_not_future],
        null=True,
        blank=True,
    )

    sputum_genexpert_result = models.CharField(
        verbose_name="Sputum Gene-Xpert results",
        max_length=45,
        choices=SPUTUM_GENEXPERT,
        default=NOT_APPLICABLE,
    )

    class Meta:
        abstract = True



from .blood_culture import BloodCultureModelAdminMixin
from .histopathology import HistopathologyModelAdminMixin
from .microbiology import MicrobiologyModelAdminMixin
from .urine_culture import UrineCultureModelAdminMixin



from django.db import models
from edc_constants.choices import YES_NO_NA
from edc_constants.constants import NOT_APPLICABLE
from edc_model.validators import date_not_future
from edc_protocol.validators import date_not_before_study_start

from ..choices import SPUTUM_CULTURE


class SputumCultureModelMixin(models.Model):
    sputum_culture_performed = models.CharField(
        verbose_name="Sputum culture performed?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    sputum_culture_date = models.DateField(
        validators=[date_not_before_study_start, date_not_future], null=True, blank=True
    )

    sputum_culture_result = models.CharField(
        verbose_name="Sputum culture results",
        max_length=10,
        choices=SPUTUM_CULTURE,
        default=NOT_APPLICABLE,
    )

    class Meta:
        abstract = True
